
# TechFlurry Controller

![build-status](https://img.shields.io/github/workflow/status/atraides/techflurry-controller/Build%20Pipeline/main?logo=GitHub)

## Author Information

Daniel Hagyárossy <[d.hagyarossy@sapstar.eu](mailto:d.hagyarossy@sapstar.eu)> \

## Copyright

Copyright (c) 2023 All rights reserved.
